==> fantacalciobazar_0.5.tar.gz: fantacalciobazar/stat_calciatore.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


include("./controlla_pass.php");
include("$percorso_cartella_dati/head.php");
if ($pass_errata != "SI") {


$partite_giocate = 0;
$somma_voti_tot = 0;
$somma_voti_giornale = 0;
for ($num1 = "01" ; $num1 < 100 ; $num1++) {
if (strlen($num1) == 1) $num1 = "0".$num1;
if ($voti = @file("$percorso_cartella_voti/voti$num1.txt")) {
$num_voti = count($voti);
for ($num2 = 0 ; $num2 < $num_voti ; $num2++) {
$dati_voto = explode($separatore_campi_file_voti, $voti[$num2]);
$num_calciatore_voto = $dati_voto[($num_colonna_numcalciatore_file_voti-1)];
$num_calciatore_voto = togli_acapo($num_calciatore_voto);
if ($num_calciatore == $num_calciatore_voto) {
$voto_tot = $dati_voto[($num_colonna_vototot_file_voti-1)];
$voto_tot = togli_acapo($voto_tot);
$voto_tot = str_replace(",",".",$voto_tot);
$voto_giornale = $dati_voto[($num_colonna_votogiornale_file_voti-1)];
$voto_giornale = togli_acapo($voto_giornale);
$voto_giornale = str_replace(",",".",$voto_giornale);
if ($voto_tot != 0 or $voto_giornale != 0) {
$partite_giocate++;
$somma_voti_tot = $somma_voti_tot + $voto_tot;
$somma_voti_giornale = $somma_voti_giornale + $voto_giornale;
} # fine if ($voto_tot != 0 or $voto_giornale != 0)
break;
} # fine if ($num_calciatore == $num_calciatore_voto)
} # fine if ($voti = @file("$percorso_cartella_voti/voti$num1.txt"))
} # fine for $num2
} # fine for $num1

if ($partite_giocate != 0) {
$media_giornale = round(($somma_voti_giornale / $partite_giocate),2);
$media_punti = round(($somma_voti_tot / $partite_giocate),2);
} # fine if ($partite_giocate != 0)
else {
$media_giornale = 0;
$media_punti = 0;
} # fine else if ($partite_giocate != 0)

$calciatori = file("$percorso_cartella_voti/calciatori.txt");
$num_calciatori = count($calciatori);
for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
$dati_calciatore = explode($separatore_campi_file_calciatori, $calciatori[$num1]);
$numero = $dati_calciatore[($num_colonna_numcalciatore_file_calciatori-1)];
$numero = togli_acapo($numero);
if ($num_calciatore == $numero) {
$nome = $dati_calciatore[($num_colonna_nome_file_calciatori-1)];
$nome = togli_acapo($nome);
$nome = ereg_replace("\"","",$nome);
if ($num_colonna_squadra_file_calciatori != 0) {
$squadra = $dati_calciatore[($num_colonna_squadra_file_calciatori-1)];
$squadra = togli_acapo($squadra);
$squadra = ereg_replace("\"","",$squadra);
} # fine if ($num_colonna_squadra_file_calciatori != 0)
$s_ruolo = $dati_calciatore[($num_colonna_ruolo_file_calciatori-1)];
$s_ruolo = togli_acapo($s_ruolo);
$ruolo = $s_ruolo;
if ($considera_fantasisti_come != "P" and $considera_fantasisti_come != "D" and $considera_fantasisti_come != "C" and $considera_fantasisti_come != "A") $considera_fantasisti_come = "F";
if ($s_ruolo == $simbolo_fantasista_file_calciatori) $ruolo = $considera_fantasisti_come;
if ($s_ruolo == $simbolo_portiere_file_calciatori) $ruolo = "P";
if ($s_ruolo == $simbolo_difensore_file_calciatori) $ruolo = "D";
if ($s_ruolo == $simbolo_centrocampista_file_calciatori) $ruolo = "C";
if ($s_ruolo == $simbolo_attaccante_file_calciatori) $ruolo = "A";
break;
} # fine if ($num_calciatore == $numero)
} # fine for $num1

echo "<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcolor=\"$sfondo_tab\">
<tr><td>Num.</td>
<td>_____________Nome_____________</td>
<td><font size=-2>Ruolo</font></td>";
if ($squadra) echo "<td align=\"center\">Squadra</td>";
echo "<td align=\"center\"><font size=-1>Partite giocate</font></td>
<td align=\"center\"><font size=-2>Media voti giornale</font></td>
<td align=\"center\"><font size=-1>Media punti</font></td></tr>
<tr><td align=\"center\">$num_calciatore</td>
<td>$nome</td>
<td align=\"center\">$ruolo</td>";
if ($squadra) echo "<td align=\"center\">$squadra</td>";
echo "<td align=\"center\">$partite_giocate</td>
<td align=\"center\">$media_giornale</td>
<td align=\"center\">$media_punti</td>
</tr></table>";

echo "<center><form method=\"post\" action=\"tab_calciatori.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"ruolo_guarda\" value=\"$ruolo_guarda\">
<input type=\"submit\" name=\"torna_mercato\" value=\"Torna indietro\">
</form></center>";



} # fine if ($pass_errata != "SI")

include("$percorso_cartella_dati/foot.php");
?>

==> fantacalciobazar_0.5.3.tar.gz: fantacalciobazar/stat_calciatore.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


include('./include/funzioni.php');
include("./controlla_pass.php");
include("$percorso_cartella_dati/head.php");
if ($pass_errata != "SI") {


$partite_giocate = 0;
$somma_voti_tot = 0;
$somma_voti_giornale = 0;
for ($num1 = "01" ; $num1 < 100 ; $num1++) {
if (strlen($num1) == 1) $num1 = "0".$num1;
if ($voti = @file("$percorso_cartella_voti/voti$num1.txt")) {
$num_voti = count($voti);
for ($num2 = 0 ; $num2 < $num_voti ; $num2++) {
$dati_voto = explode($separatore_campi_file_voti, $voti[$num2]);
$num_calciatore_voto = $dati_voto[($num_colonna_numcalciatore_file_voti-1)];
$num_calciatore_voto = togli_acapo($num_calciatore_voto);
if ($num_calciatore == $num_calciatore_voto) {
$voto_tot = $dati_voto[($num_colonna_vototot_file_voti-1)];
$voto_tot = togli_acapo($voto_tot);
$voto_tot = str_replace(",",".",$voto_tot);
$voto_giornale = $dati_voto[($num_colonna_votogiornale_file_voti-1)];
$voto_giornale = togli_acapo($voto_giornale);
$voto_giornale = str_replace(",",".",$voto_giornale);
if ($voto_giornale or ($voto_tot and $voto_tot <= 3)) {
$partite_giocate++;
$somma_voti_tot = $somma_voti_tot + $voto_tot;
$somma_voti_giornale = $somma_voti_giornale + $voto_giornale;
} # fine if ($voto_giornale or ($voto_tot and $voto_tot <= 3))
break;
} # fine if ($num_calciatore == $num_calciatore_voto)
} # fine if ($voti = @file("$percorso_cartella_voti/voti$num1.txt"))
} # fine for $num2
} # fine for $num1

if ($partite_giocate != 0) {
$media_giornale = round(($somma_voti_giornale / $partite_giocate),2);
$media_punti = round(($somma_voti_tot / $partite_giocate),2);
} # fine if ($partite_giocate != 0)
else {
$media_giornale = 0;
$media_punti = 0;
} # fine else if ($partite_giocate != 0)

$calciatori = file("$percorso_cartella_voti/calciatori.txt");
$num_calciatori = count($calciatori);
for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
$dati_calciatore = explode($separatore_campi_file_calciatori, $calciatori[$num1]);
$numero = $dati_calciatore[($num_colonna_numcalciatore_file_calciatori-1)];
$numero = togli_acapo($numero);
if ($num_calciatore == $numero) {
$nome = $dati_calciatore[($num_colonna_nome_file_calciatori-1)];
$nome = togli_acapo($nome);
$nome = preg_replace("/\"/","",$nome);
if ($num_colonna_squadra_file_calciatori != 0) {
$squadra = $dati_calciatore[($num_colonna_squadra_file_calciatori-1)];
$squadra = togli_acapo($squadra);
$squadra = preg_replace("/\"/","",$squadra);
} # fine if ($num_colonna_squadra_file_calciatori != 0)
$s_ruolo = $dati_calciatore[($num_colonna_ruolo_file_calciatori-1)];
$s_ruolo = togli_acapo($s_ruolo);
$ruolo = $s_ruolo;
if ($considera_fantasisti_come != "P" and $considera_fantasisti_come != "D" and $considera_fantasisti_come != "C" and $considera_fantasisti_come != "A") $considera_fantasisti_come = "F";
if ($s_ruolo == $simbolo_fantasista_file_calciatori) $ruolo = $considera_fantasisti_come;
if ($s_ruolo == $simbolo_portiere_file_calciatori) $ruolo = "P";
if ($s_ruolo == $simbolo_difensore_file_calciatori) $ruolo = "D";
if ($s_ruolo == $simbolo_centrocampista_file_calciatori) $ruolo = "C";
if ($s_ruolo == $simbolo_attaccante_file_calciatori) $ruolo = "A";
break;
} # fine if ($num_calciatore == $numero)
} # fine for $num1

echo "<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcolor=\"$sfondo_tab\">
<tr><td>Num.</td>
<td>_____________Nome_____________</td>
<td><font size=-2>Ruolo</font></td>";
if ($squadra) echo "<td align=\"center\">Squadra</td>";
echo "<td align=\"center\"><font size=-1>Partite giocate</font></td>
<td align=\"center\"><font size=-2>Media voti giornale</font></td>
<td align=\"center\"><font size=-1>Media punti</font></td></tr>
<tr><td align=\"center\">$num_calciatore</td>
<td>$nome</td>
<td align=\"center\">$ruolo</td>";
if ($squadra) echo "<td align=\"center\">$squadra</td>";
echo "<td align=\"center\">$partite_giocate</td>
<td align=\"center\">$media_giornale</td>
<td align=\"center\">$media_punti</td>
</tr></table>";

echo "<center><form  accept-charset=\"utf-8\" method=\"post\" action=\"tab_calciatori.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"ruolo_guarda\" value=\"$ruolo_guarda\">
<input type=\"submit\" name=\"torna_mercato\" value=\"Torna indietro\">
</form></center>";



} # fine if ($pass_errata != "SI")

include("$percorso_cartella_dati/foot.php");
?>
